@@ -79,7 +79,7 @@ enum {
 static guint signals[LAST_SIGNAL];
 static GParamSpec *properties[N_PROPERTIES] = { NULL };
 
-G_DEFINE_TYPE (PeasGtkPluginManagerView, peas_gtk_plugin_manager_view, GTK_TYPE_TREE_VIEW);
+G_DEFINE_TYPE (PeasGtkPluginManagerView, peas_gtk_plugin_manager_view, GTK_TYPE_TREE_VIEW)
 
 static void
 convert_iter_to_child_iter (PeasGtkPluginManagerView *view,
@@ -611,19 +611,13 @@ peas_gtk_plugin_manager_view_query_tooltip (GtkWidget  *widget,
   info = peas_gtk_plugin_manager_store_get_plugin (view->priv->store, &iter);
 
   if (peas_plugin_info_is_available (info, &error))
-    {
-      gtk_tree_model_get (GTK_TREE_MODEL (view->priv->store), &iter,
-        PEAS_GTK_PLUGIN_MANAGER_STORE_INFO_COLUMN, &message,
-        -1);
-    }
-  else
-    {
-      message = g_markup_printf_escaped (_("<b>The plugin '%s' could not be "
-                                           "loaded</b>\nAn error occurred: %s"),
-                                         peas_plugin_info_get_name (info),
-                                         error->message);
-      g_error_free (error);
-    }
+    return FALSE;
+
+  message = g_markup_printf_escaped (_("<b>The plugin '%s' could not be "
+                                       "loaded</b>\nAn error occurred: %s"),
+                                     peas_plugin_info_get_name (info),
+                                     error->message);
+  g_error_free (error);
 
   gtk_tooltip_set_markup (tooltip, message);
 
