@@ -55,7 +55,7 @@ typedef struct {
 static gboolean   peas_plugin_loader_python_add_module_path (PeasPluginLoaderPython *pyloader,
                                                              const gchar            *module_path);
 
-G_DEFINE_TYPE (PeasPluginLoaderPython, peas_plugin_loader_python, PEAS_TYPE_PLUGIN_LOADER);
+G_DEFINE_TYPE (PeasPluginLoaderPython, peas_plugin_loader_python, PEAS_TYPE_PLUGIN_LOADER)
 
 G_MODULE_EXPORT void
 peas_register_types (PeasObjectModule *module)
@@ -375,8 +375,9 @@ static gboolean
 peas_plugin_loader_python_initialize (PeasPluginLoader *loader)
 {
   PeasPluginLoaderPython *pyloader = PEAS_PLUGIN_LOADER_PYTHON (loader);
+  PyGILState_STATE state = 0;
   long hexversion;
-  PyObject *mdict, *gettext, *install, *gettext_args;
+  PyObject *gettext, *result;
   const gchar *prgname;
 #if PY_VERSION_HEX < 0x03000000
   const char *argv[] = { NULL, NULL };
@@ -390,7 +391,11 @@ peas_plugin_loader_python_initialize (PeasPluginLoader *loader)
   pyloader->priv->init_failed = TRUE;
 
   /* Python initialization */
-  if (!Py_IsInitialized ())
+  if (Py_IsInitialized ())
+    {
+      state = PyGILState_Ensure ();
+    }
+  else
     {
 #ifdef HAVE_SIGACTION
       struct sigaction sigint;
@@ -491,16 +496,25 @@ peas_plugin_loader_python_initialize (PeasPluginLoader *loader)
       goto python_init_error;
     }
 
-  mdict = PyModule_GetDict (gettext);
-  install = PyDict_GetItemString (mdict, "install");
-  gettext_args = Py_BuildValue ("ss", GETTEXT_PACKAGE, PEAS_LOCALEDIR);
-  PyObject_CallObject (install, gettext_args);
-  Py_DECREF (gettext_args);
+  result = PyObject_CallMethod (gettext, "install", "ss",
+                                GETTEXT_PACKAGE, PEAS_LOCALEDIR);
+  Py_XDECREF (result);
+
+  if (PyErr_Occurred ())
+    {
+      g_warning ("Error initializing Python Plugin Loader: "
+                 "failed to install gettext");
+
+      goto python_init_error;
+    }
 
   /* Python has been successfully initialized */
   pyloader->priv->init_failed = FALSE;
 
-  pyloader->priv->py_thread_state = PyEval_SaveThread ();
+  if (!pyloader->priv->must_finalize_python)
+    PyGILState_Release (state);
+  else
+    pyloader->priv->py_thread_state = PyEval_SaveThread ();
 
   return TRUE;
 
@@ -512,6 +526,9 @@ python_init_error:
   if (PyErr_Occurred ())
     PyErr_Clear ();
 
+  if (!pyloader->priv->must_finalize_python)
+    PyGILState_Release (state);
+
   return FALSE;
 }
 
