@@ -37,6 +37,7 @@ static int n_windows;
 
 static GOptionEntry demo_args[] = {
   { "run-from-build-dir", 'b', 0, G_OPTION_ARG_NONE, &run_from_build_dir,
+    /* Translators: The directory in which the demo program was compiled at */
     N_("Run from build directory"), NULL },
   { NULL }
 };
@@ -124,6 +125,8 @@ main (int    argc,
   peas_engine_add_search_path (engine, plugin_dir, plugin_dir);
   g_free (plugin_dir);
 
+  /* We don't care about leaking memory */
+  g_setenv ("PEAS_ALLOW_ALL_LOADERS", "1", TRUE);
   peas_engine_enable_loader (engine, "python3");
   peas_engine_enable_loader (engine, "seed");
 
